UserReturnIrqPolicy

Enum UserReturnIrqPolicy 

pub enum UserReturnIrqPolicy {
    Inherit,
    Enable,
    Disable,
}
Policy for whether user-mode should run with IRQs enabled immediately after returning from the kernel (e.g. sret/eret).

Variants



Inherit

Do not change the interrupt state; honor the trapframe/arch default.



Enable

Ensure IRQs are enabled right after returning to user mode.



Disable

Ensure IRQs are disabled right after returning to user mode.