configure_user_entry

Function configure_user_entry 

pub fn configure_user_entry(
    trapframe: &mut Trapframe,
    options: UserEntryOptions,
)
Configure architecture-specific state for the upcoming return to user mode.

This is intended to be called immediately before the final trampoline/exit jump that performs sret/eret.