pub fn configure_user_entry(
trapframe: &mut Trapframe,
options: UserEntryOptions,
)Expand description
Configure architecture-specific state for the upcoming return to user mode.
This is intended to be called immediately before the final trampoline/exit
jump that performs sret/eret.